Skip to contents

Provides an interactive console browser for exploring the Gene Ontology hierarchy. The user can navigate through parent–child relationships, add nodes of interest, and return the selected GO IDs.

Usage

browse_go(go)

Arguments

go

A GO or GOSubgraph object.

Value

A list with two elements:

  • ids: character() vector of selected GO IDs.

  • summary: data.frame summarizing the selected terms.

Examples

data("go_cc", package = "GOcontext")

if (interactive()) {
    res <- browse_go(go_cc)
    res$ids
    res$summary
}